@@ -55,9 +55,6 @@ def plot_waterfall(wf, f_start=None, f_stop=None, **kwargs):
     frequency of the expected event.
     """
 
-    # Extract source name.
-    source_name = wf.header["source_name"]
-
     # prepare font
     matplotlib.rc("font", **font)
 
@@ -81,10 +78,13 @@ def plot_waterfall(wf, f_start=None, f_stop=None, **kwargs):
         wf.info()
         raise ValueError("*** Something is wrong with the grab_data output!") from ex
 
-    # Rolled back PR #82
-
     # determine extent of the plotting panel for imshow
-    extent=(plot_f[0], plot_f[-1], (wf.timestamps[-1]-wf.timestamps[0])*24.*60.*60, 0.0)
+    nints = plot_data.shape[0]
+    bottom = (nints - 1) * wf.header["tsamp"] # in seconds
+    extent=(plot_f[0], # left
+            plot_f[-1], # right
+            bottom, # bottom
+            0.0) # top
 
     # plot and scale intensity (log vs. linear)
     kwargs["cmap"] = kwargs.get("cmap", "viridis")
@@ -104,13 +104,9 @@ def plot_waterfall(wf, f_start=None, f_stop=None, **kwargs):
         **kwargs
     )
 
-    # add plot labels
-    plt.xlabel("Frequency [Hz]",fontdict=font)
-    plt.ylabel("Time [s]",fontdict=font)
-
     # add source name
     ax = plt.gca()
-    plt.text(0.03, 0.8, source_name, transform=ax.transAxes, bbox=dict(facecolor="white"))
+    plt.text(0.03, 0.8, wf.header["source_name"], transform=ax.transAxes, bbox=dict(facecolor="white"))
 
     return this_plot
 
@@ -122,20 +118,41 @@ def sort2(x, y):
     return x, y
 
 
-def make_waterfall_plots(file_list, plot_dir, f_start=None, f_stop=None, **kwargs):
+def ck_lt_bdry(x, bdry):
+    if np.isclose(x, bdry, atol=1e-6):
+        return False # assumed equal
+    if x < bdry:
+        return True # below lower boundary
+    return False # above lower boundary
+
+
+def ck_gt_bdry(x, bdry):
+    if np.isclose(x, bdry, atol=1e-6):
+        return False # assumed equal
+    if x > bdry:
+        return True # above upper boundary
+    return False # below upper boundary
+
+
+def make_waterfall_plots(file_list, plot_dir, plot_dpi, height_ratios, f_start=None, f_stop=None, **kwargs):
     r"""
     Make waterfall plots of a file set, view from top to bottom.
 
     Parameters
     ----------
-    file_list : str
-        List of filterbank files to plot in a stacked mode.
+    file_list : list
+        List of filterbank file paths to plot in a stacked mode.
+    plot_dir : str
+        Path of where to store the output plot file (png).
+    plot_dpi : int
+        Number of dots per inch for the plots.
+    height_ratios : list
+        A list whose elements are the observation length for each file in order
+        indicated by parameter file_list.
     f_start : float
         Start frequency, in MHz.
     f_stop : float
         Stop frequency, in MHz.
-    source_name_list : list
-        List of source names in the set, in order.
     kwargs : dict
         Keyword args to be passed to matplotlib imshow().
     """
@@ -145,7 +162,12 @@ def make_waterfall_plots(file_list, plot_dir, f_start=None, f_stop=None, **kwarg
 
     # set up the sub-plots
     n_plots = len(file_list)
-    fig = plt.subplots(n_plots, sharex=True, sharey=True,figsize=(10, 2*n_plots))
+    fig_array = plt.subplots(n_plots,
+                             sharex=True,
+                             sharey=False, 
+                             dpi=plot_dpi,
+                             figsize=(10, 2*n_plots),
+                             gridspec_kw={"height_ratios" : height_ratios})
 
     # get directory path for storing PNG files
     if plot_dir is None:
@@ -155,71 +177,60 @@ def make_waterfall_plots(file_list, plot_dir, f_start=None, f_stop=None, **kwarg
             os.mkdir(plot_dir)
         dirpath = plot_dir
 
+    # read in header for the first panel
+    wf = bl.Waterfall(file_list[0], load_data=False)
+    tstart = wf.header["tstart"]
+    source_name = wf.header["source_name"]
 
-    # read in data for the first panel
-    max_load = bl.calcload.calc_max_load(file_list[0])
-    #print("plot_event make_waterfall_plots: max_load={} is required for {}".format(max_load, file_list[0]))
-    wf1 = bl.Waterfall(file_list[0], max_load=max_load)
-    t0 = wf1.header["tstart"]
-    source_name = wf1.header["source_name"]
-
-    # Fix frequency boundaries if required.
-    freqs = wf1.container.populate_freqs()
+    # Compute the lowest and highest valued frequencies.
+    freqs = wf.get_freqs()
     if f_start is None:
         f_start = freqs[0]
     if f_stop is None:
         f_stop = freqs[-1]
     the_lowest, the_highest = sort2(f_start, f_stop)
 
-    # rebin data to plot correctly with fewer points
-    plot_f1, plot_data1 = wf1.grab_data(f_start=the_lowest, f_stop=the_highest)
-    dec_fac_x, dec_fac_y = 1, 1
-    if plot_data1.shape[0] > MAX_IMSHOW_POINTS[0]:
-        dec_fac_x = plot_data1.shape[0] / MAX_IMSHOW_POINTS[0]
-    if plot_data1.shape[1] > MAX_IMSHOW_POINTS[1]:
-        dec_fac_y =  int(np.ceil(plot_data1.shape[1] /  MAX_IMSHOW_POINTS[1]))
-    plot_data1 = rebin(plot_data1, dec_fac_x, dec_fac_y)
-
-    # Compute the midpoint.
+    # Compute the midpoint frequency for the x-axis.
     the_midpoint = np.abs(the_lowest + the_highest) / 2.
 
-    # Protect RAM utilisation.
-    del wf1, freqs, plot_f1, plot_data1
-    gc.collect()
-
     # Fill in each subplot for the full plot
     subplots = []
+    count = 0
     for ii, filename in enumerate(file_list):
         logger.debug("make_waterfall_plots: file {} in list: {}".format(ii, filename))
-        # identify panel
+
+        # Identify panel.
         subplot = plt.subplot(n_plots, 1, ii + 1)
         subplots.append(subplot)
 
-        # read in data
-        max_load = bl.calcload.calc_max_load(filename)
-        wf = bl.Waterfall(filename, max_load=max_load)
+        # Read file header and data.
+        wf = bl.Waterfall(filename, f_start=the_lowest, f_stop=the_highest)
 
         # Validate frequency range.
         freqs = wf.container.populate_freqs()
         ii_lowest, ii_highest = sort2(freqs[0], freqs[-1])
         logger.info("Processing: {}, freq lowest={}, highest={}".format(filename, ii_lowest, ii_highest))
-        if the_lowest < ii_lowest or the_highest > ii_highest:
+        if ck_lt_bdry(ii_lowest, the_lowest) or ck_gt_bdry(ii_highest, the_highest):
+            logger.warning("Frequency range not compatible!  the_lowest={}, ii_lowest={}."
+                           .format(the_lowest, ii_lowest))
+            logger.warning("Frequency range not compatible!  the_highest={}, ii_highest={}."
+                           .format(the_highest, ii_highest))
             logger.warning("Frequency range not compatible!  Ignoring this file.")
             # Protect RAM utilisation.
             del wf, freqs
             gc.collect()
             continue # Skip this file.
 
-        # make plot with plot_waterfall
-        source_name = wf.header["source_name"]
-        this_plot = plot_waterfall(wf,
+        # Plot the waterfall for the current figure.
+        last_plot = plot_waterfall(wf,
                                    f_start=the_lowest,
                                    f_stop=the_highest,
                                    **kwargs)
+        count += 1
 
         # Title the full plot if processing the first file.
         if ii == 0:
-            plot_title = "%s \n MJD:%5.5f (first file)" % (source_name, t0)
+            plot_title = "%s \n MJD:%5.5f (first file)" % (source_name, tstart)
             plt.title(plot_title)
 
         # Format full plot.
@@ -230,6 +241,11 @@ def make_waterfall_plots(file_list, plot_dir, f_start=None, f_stop=None, **kwarg
         del wf, freqs
         gc.collect()
 
+    # Any plots performed?
+    if count < 1:
+        logger.error("No plots performed!")
+        sys.exit(86)
+
     # More overall plot formatting, axis labelling.
     factor = 1e6
     units = "Hz"
@@ -241,16 +257,21 @@ def make_waterfall_plots(file_list, plot_dir, f_start=None, f_stop=None, **kwarg
     plt.xticks(xloc, xticks)
     plt.xlabel("Relative Frequency [%s] from %f MHz" % (units, the_midpoint), fontdict=font)
 
+    # add plot labels
+    plt.xlabel("Frequency [Hz]",fontdict=font)
+    plt.ylabel("Time [s]",fontdict=font)
+
     # Add colorbar.
-    cax = fig[0].add_axes([0.94, 0.11, 0.03, 0.77])
-    fig[0].colorbar(this_plot, cax=cax, label="Normalized Power (Arbitrary Units)")
+    cax = fig_array[0].add_axes([0.94, 0.11, 0.03, 0.77])
+    fig_array[0].colorbar(last_plot, cax=cax, label="Normalized Power (Arbitrary Units)")
 
     # Adjust plots
-    plt.subplots_adjust(hspace=0,wspace=0)
+    plt.subplots_adjust(hspace=0.02, wspace=0.02)
 
     # Save the figures.
-    path_png = dirpath + source_name + "_fstart_{:0.6f}".format(f_start) \
-                + "_fstop_{:0.6f}".format(f_stop) + ".png"
+    path_png = dirpath + "stax_fstart_{:0.1f}".format(f_start) \
+                + "_fstop_{:0.1f}".format(f_stop) \
+                + "_dpi_{}".format(plot_dpi) + ".png"
     plt.savefig(path_png, bbox_inches="tight")
     logger.info("Saved plot: {}".format(path_png))
 
@@ -268,9 +289,11 @@ def cmd_tool(args=None):
     r"""Coomand line parser"""
     parser = ArgumentParser(description='Make waterfall plots from a set of files, viewed from top to bottom.')
     parser.add_argument('file_list', type=str, nargs='+', help='List of files to plot')
-    parser.add_argument('-f_start', type=float, default=None, help='Start frequency.  Default: None.')
-    parser.add_argument('-f_stop', type=float, default=None, help='Stop frequency.  Default: None.')
-    parser.add_argument('-plot_dir', type=str, default=".", help='Directory to receive the plot (.png).  Default: current directory.')
+    parser.add_argument('--f_start', type=float, default=None, help='Start frequency.  Default: None.')
+    parser.add_argument('--f_stop', type=float, default=None, help='Stop frequency.  Default: None.')
+    parser.add_argument('--plot_dir', '-p', type=str, default=".", help='Directory to receive the plot (.png).  Default: current directory.')
+    parser.add_argument("--dpi", "-d", type=int, default=200,
+                        help="Image file dots per inch.  Default: 200.")
     if args is None:
         args = parser.parse_args()
     else:
@@ -278,12 +301,27 @@ def cmd_tool(args=None):
     if args.file_list == []:
         os.system("stax -h")
         sys.exit(0)
+    args.plot_dir += "/"
+
+    # Get file paths in alphabetical order.
+    args.file_list = sorted(args.file_list)
+
+    # Compute the array of height ratios.
+    height_ratios = []
+    for file in args.file_list:
+        wf = bl.Waterfall(file, max_load=1)
+        nints = wf.file_shape[0]
+        height_ratios.append((nints - 1) * wf.header["tsamp"])
+        del wf
 
     # Make the plots.
-    args.plot_dir += "/"
-    args.file_list = sorted(args.file_list)
     logger.info("Begin")
-    make_waterfall_plots(args.file_list, args.plot_dir, args.f_start, args.f_stop)
+    make_waterfall_plots(args.file_list,
+                         args.plot_dir,
+                         args.dpi,
+                         height_ratios,
+                         args.f_start,
+                         args.f_stop)
     logger.info("End")
 
 
